#!/bin/bash

# detect java
if which java >/dev/null; then
    _java=java
elif [[ -n "$JAVA_HOME" ]] && [[ -x "$JAVA_HOME/bin/java" ]];  then
    _java="$JAVA_HOME/bin/java"
else
    echo "No java detected! Please install it from https://java.com/download"; exit 0
fi

if [[ "$_java" ]]; then
    version=$("$_java" -version 2>&1 | awk -F '"' '/version/ {print $2}')
    if [[ "$version" < "1.7" ]]; then
        echo "Java version is less than 1.7. Please update it."; exit 0;
    fi
fi

if [ "$#" -ne 2 ]; then
    echo "Illegal number of parameters for ProMC to SLCIO converter"
    echo "Usage: promc2lcio.sh input.promc output.slcio"  
    exit 1;
fi

INPUT=$1
OUTPUT=$2
echo "Creating LCIO.."
echo "INPUT=$INPUT"
echo "OUTPUT=$OUTPUT"
#INPUT="files/pgun_muon32gev_001.promc"
#OUTPUT="files/pgun_muon32gev_001.slcio"
rm -f $OUTPUT

CFILE="promc2lcio.sh"
export FPADSIM=`pwd`
if [ ! -f $CFILE ];
then
   export FPADSIM="$( cd "$( echo "${BASH_SOURCE[0]%/*}" )" && pwd )"
fi
echo "Setup dir=$FPADSIM"


LCIO_VERSION=2.7.4
export PROMC_LCIO=$FPADSIM/promc2other
export CLASSPATH=$CLASSPATH:$PROMC_LCIO:$PROMC_LCIO/lib/freehep-mcfio-2.0.1.jar:$PROMC_LCIO/lib/lcio-${LCIO_VERSION}-SNAPSHOT-bin.jar:$PROMC_LCIO/lib/freehep-xdr-2.0.3.jar:$PROMC_LCIO/lib/browser_promc.jar


java promc2lcio ${INPUT} ${OUTPUT}
