#!/bin/bash

# detect java
if which java >/dev/null; then
    _java=java
elif [[ -n "$JAVA_HOME" ]] && [[ -x "$JAVA_HOME/bin/java" ]];  then
    _java="$JAVA_HOME/bin/java"
else
    echo "No java detected! Please install it from https://java.com/download"; exit 0
fi

if [[ "$_java" ]]; then
    version=$("$_java" -version 2>&1 | awk -F '"' '/version/ {print $2}')
    if [[ "$version" < "1.7" ]]; then
        echo "Java version is less than 1.7. Please update it."; exit 0;
    fi
fi

if [ "$#" -ne 2 ]; then
    echo "Illegal number of parameters for ProMC to STDHEP converter"
    echo "Usage: promc2stdhep.sh input.promc output.stdhep"  
    exit 1;
fi


INPUT=$1
OUTPUT=$2
echo "Creating STDHEP.."
echo "INPUT=$INPUT"
echo "OUTPUT=$OUTPUT"
#INPUT="files/pgun_muon32gev_001.promc"
#OUTPUT="files/pgun_muon32gev_001.slcio"
rm -f $OUTPUT

CFILE="promc2stdhep.sh"
export FPADSIM=`pwd`
if [ ! -f $CFILE ];
then
   export FPADSIM="$( cd "$( echo "${BASH_SOURCE[0]%/*}" )" && pwd )"
fi
echo "Setup dir=$FPADSIM"


#export JAVA_HOME=$FPADSIM/jdk1.8.0_131
#export PATH=$JAVA_HOME/bin:$PATH
#export LD_LIBRARY_PATH=$JAVA_HOME/lib:$LD_LIBRARY_PATH

# promc converter
export PROMC_STDHEP=$FPADSIM/promc2other
export CLASSPATH=$CLASSPATH:$PROMC_STDHEP:$PROMC_STDHEP/lib/freehep-mcfio-2.0.1.jar:$PROMC_STDHEP/lib/freehep-stdhep-2.0.1.jar:$PROMC_STDHEP/lib/freehep-xdr-2.0.3.jar:$PROMC_STDHEP/lib/browser_promc.jar

java promc2stdhep ${INPUT} ${OUTPUT}
